@@ -4,7 +4,7 @@ from simplecommand import CommandException
 from simplecommand.log import logger
 
 
-def run_command_over_ssh(username, host, port, keyfile, command):
+def run_command_over_ssh(username, host, port, command, keyfile=''):
     log = logger(name='ssh', logfile='/tmp/ssh_output.%s' % time.strftime("%Y%m%d%H%M%S"))
     ssh_cmd = get_ssh_command(user=username, host=host, port=port, keyfile=keyfile, command=command)
     output = []
